@@ -28,6 +28,7 @@ if [ -z "$SED" ]; then
   echo
   echo "This installation script requires (GNU) sed."
   echo "Please install it before to run this script."
+  echo "If it is already installed on your system be sure that it is in the PATH"
   exit 99
 fi
 echo "Done"
@@ -38,14 +39,36 @@ if [ -z "$AWK" ]; then
   echo
   echo "Rot[t]Log script requires GNU awk."
   echo "Please install it before to run this script."
+  echo "If it is already installed on your system be sure that it is in the PATH"
   exit 99
 fi
 echo "Done"
 
+echo -n "Checking for grep..."
+GREP="$(which grep)"
+if [ -z "$GREP" ]; then
+  echo
+  echo "Rot[t]Log script requires GNU grep."
+  echo "Please install it before to run this script."
+  echo "If it is already installed on your system be sure that it is in the PATH"
+  exit 99
+fi
+echo "Done"
+
+echo -n "Checking for util-linux"
+UTIL="$(which cal)"
+if [ -z "$UTIL" ]; then
+  echo
+  echo "Rot[t]Log script requires cal (from util-linux)."
+  echo "Please install it before to run this script."
+  echo "If it is already installed on your system be sure that it is in the PATH"
+  exit 99
+fi
+
 source ./DefConf.inc
 
-DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc"
-MANFILES="rottlog.8 rottlogconf.5 rottlogex.5"
+DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc sample_custom"
+MANFILES="rottlog.8 rottlogconf.5 rottlogex.5 rottlogrc.5"
 
 echo "Updating bash codes... "
 
@@ -96,9 +119,12 @@ rm -f $BINDIR/virott[rc,month,day,week]*
 
 install -o $LOG_OWN -g $LOG_GROUP -m $LOG_MODE rottlog $BINDIR
 install -o $LOG_OWN -g $LOG_GROUP -m $LOG_MODE virottrc $BINDIR
-ln -sf $BINDIR/virottrc $BINDIR/virottday
-ln -sf $BINDIR/virottrc $BINDIR/virottweek
-ln -sf $BINDIR/virottrc $BINDIR/virottmonth
+for i in custom day week month; do
+  ln -sf $BINDIR/virottrc $BINDIR/virott$i
+done
+#ln -sf $BINDIR/virottrc $BINDIR/virottday
+#ln -sf $BINDIR/virottrc $BINDIR/virottweek
+#ln -sf $BINDIR/virottrc $BINDIR/virottmonth
 
 mkdir -p $DOCDIR/rottlog-$VERSION
 for D in $DOCFILES; do
@@ -128,8 +154,8 @@ chmod $STAT_MODE $ROTT_STATPATH
 
 echo "Installation finished. Now Rot[t]Log can be used in command line mode"
 echo "or using crontab."
-echo "If there are some bug please send me an e-mail explaining to me problems"
-echo "at address: stefko5@inwind.it"
-
+echo "If you find some bug please send me an e-mail explaining to me problems"
+echo "and as much as possible information at address: stefko5@inwind.it"
+echo
 
 
